clear
set mem 100m
set maxvar 10000

tempfile temp

use "Training_Ghana.dta"

keep lw06 newraven neweng newrdg newmath cityG1 cityG2 cityG3 cityG4 income student broeduc siseduc /*
*/ siblings appcost traintime apptraintime educ educsq dadeduc momeduc age agesq male /*
*/ hhcreditaccess othcreditaccess hhotherapp waterinhome wevocskills apppast app_ever app_now occup /*
*/ lhours kdistsec kdistprim hhhead vocpast ehighest prim jssormid sss postsec

set more off

label variable kdistprim "Distance to primary school (km)"
label var kdistsec "Distance to secondary school (km)"
label var momeduc "Mother's education (years)"
label var dadeduc "Father's education (years)"
label var hhotherapp "Number of other apprentices in HH"
label var hhhead "HH head"
label var appcost "App fee"
label var siblings "Number of Siblings"

label variable lw06 "Ln Monthly earnings in 2006 cedis"
label variable neweng "English Score"
label variable newmath "Math Score"
label variable newrdg "Reading Score"
label variable student "=1 if student"
label variable wevocskills "Training skills"
label var ehighest "Highest educ"
label var occup "Occupation"
label var app_now "Current apprentice"
label var app_ever "App ever"

/* recreate experience variable -- assuming either 3 years of apprenticeship or trying to calculate it directly.
this is complicated by the fact that the time reported for completing training includes vocational training too. */

gen exper = age-educ-6-traintime if apppast==1 | vocpast==1
replace exper = age-educ-6 if ehighest=="technical2"  /* these guys get their training years lumped into educ */
replace exper = age-educ-6 if apppast==0 & vocpast==0
replace exper = 0 if exper<0

gen expersq=(exper^2)/100

label var exper "Experience (years)"
label var expersq "Experience$^2$ (years$^2$/100)"


global x_earn      = "lhours male exper expersq educ educsq" 
global g_cities    = "cityG2 cityG3 cityG4"
global skills      = "newraven neweng newrdg newmath"
global z_educ      = "broeduc siseduc"
global z_app_new   = "hhotherapp waterinhome hhcreditaccess "
global z_int3	= " hhotherappdmeduc waterinhomedmeduc hhcreditaccessdmeduc "



/* setting up sample : drop students, old people (over 65!!!) and kids, current apprentices */

drop if student==1
drop if age<18
drop if age>65

/* drop people who report earnings but aren't actually working -- anomolies */
drop if lw06!=. & occup==5
drop if apppast==.

/* restrict to income earners */
drop if lw06==.


/* leave out current apprentices because they have erratic earnings */

drop if app_now==1


/* CAUTION!!!!  replace missings with averages for instruments that are continous variables*/
egen avgotherapp=mean(hhotherapp)
replace hhotherapp=avgotherapp if hhotherapp==.

egen avgbroeduc=mean(broeduc)
egen avgsiseduc=mean(siseduc)
replace broeduc=avgbroeduc if broeduc==.
replace siseduc=avgsiseduc if siseduc==.
label var broeduc "Brother's education (years)"
label var siseduc "Sister's education (years)"

replace lhours=ln(40) if lw06!=. & lhours==. & occup!=5


/* average doesn't convey the correct meaning for binary vars, replace with zero */
replace waterinhome=0 if waterinhome==.
label var waterinhome "Piped internal water in home"
label var othcreditaccess "Other hh members have credit"
label var hhcreditaccess "HH borrowed in past year"

label var lhours "Ln(hrs worked per week)"
label var newraven "Raven's score"

/* generate instrument interaction terms for wooldridge procedure 18.2 */
foreach var in $z_app_new{
	gen `var'educ = `var' * educ 
	gen `var'educsq = `var' * educsq 
	gen `var'exper = `var' * exper
	gen `var'expersq = `var' * expersq
	gen `var'male = `var' * male 
	gen `var'lhours = `var' * lhours 
}


foreach var in $x_earn{
	gen `var'male = `var' * male 
}


foreach var in $x_earn{
	gen app`var'=apppast * `var'
	egen avg`var'=mean(`var')
	gen dm`var'=`var'-avg`var'
}


label variable appeduc "App x Education"
label variable appeducsq "App x Education$^2$/100"
label var appexper "App x Experience"
label var appexpersq "App x Experience$^2$/100"
gen appdmeduc=apppast*dmeduc
label variable appdmeduc "App x (Ed-$\mathrm{\bar{Ed}}$)"
gen appdmeducsq=apppast*dmeducsq
label variable appdmeducsq "App x (Educ$^2$/100-mean)"
gen appdmexper=apppast*dmexper
label var appdmexper "App x (Exper-mean)"
gen appdmexpersq = apppast*dmexpersq
label var appdmexpersq "App x (Exper$^2$/100-mean)"
gen appdmmale= apppast*dmmale
label var appdmmale "App x (Male-mean)"
gen appdmlhours=apppast*dmlhours 
label var appdmlhours "App x (Ln(hours)-mean)"
label variable appmale "App x Male"

foreach var in $z_app_new{
	gen `var'dmeduc = `var' * dmeduc 
	gen `var'dmeducsq = `var' * dmeducsq 
	gen `var'dmexper = `var' * dmexper
	gen `var'dmexpersq = `var' * dmexpersq
	gen `var'dmmale = `var' * dmmale 
	gen `var'dmlhours = `var' * dmlhours 
}



foreach program in start baseline1 baseline2 baseline3 earnskills educonly interaction app2sls wool181 app2slsint wool182 /*
	*/ linapp1 linapp2 linapp3 linfullmodel /*
	*/ earnskillsint1 earnskillsint2 card gender nocontrol{
	capture program drop `program'
}



/* program definitions */

program define start
	reg lw06 apppast $g_cities if lw06!=., robust
end

program define baseline1
	reg lw06 $x_earn $g_cities if lw06!=., robust
end

program define baseline2
	reg lw06 $x_earn apppast $g_cities if lw06!=., robust
end

program define earnskills
	reg lw06 $x_earn apppast $g_cities $skills, robust 
end

program define educonly 
	reg lw06 $x_earn apppast control $g_cities $skills, robust 
end

program define nocontrol 
	reg lw06 $x_earn apppast appdmeduc $g_cities $skills, robust 
end


program define interaction 
	reg lw06 $x_earn apppast control appdmeduc $g_cities $skills, robust 
end

/* IV approach for apprenticeship, using standard 2SLS and then Wooldridge's efficiency correction */
program define app2sls 	
	ivreg lw06 $x_earn (apppast = $z_app_new) control $g_cities $skills, robust 
end

program define wool181
	ivreg lw06 $x_earn (apppast = apphat181) control $g_cities $skills, robust 
end

program define app2slsint 	
	ivreg lw06 $x_earn (appdmeduc apppast = $z_app_new $z_int3) control $g_cities $skills, robust 
end

program define wool182
 	ivreg lw06 $x_earn (appdmeduc apppast = apphat182 dmeducah) control $g_cities $skills, robust
end

/* programs for the control function approach to app */


program define linfullmodel
	reg lw06 $x_earn apppast appdmeduc  applin control $g_cities $skills, robust 
end




**************************************
*** control function for education ***
**************************************


/* best for overid test */
ivreg lw06 male lhours exper expersq (educ = siseduc broeduc ) $g_cities $skills, first
overid

reg educ lhours male exper expersq  $z_educ $g_cities $skills if lw06!=., robust 
	predict control, r
label variable control "Educ Control"

****************************************
*** 1st stage probit a la Wooldridge ***
****************************************

/* procedure 18.1 */
probit apppast $x_earn $z_app_new $g_cities $skills control if lw06!=., robust
	predict apphat181 

/* procedure 18.2 */
probit apppast $x_earn $z_app_new $g_cities $skills control if lw06!=., robust
	predict apphat182

foreach var in dmeduc dmeducsq dmexper dmexpersq{
	gen `var'ah = `var' * apphat182
}

/* a regression to prove identification of app separately from educ */
reg educ male exper expersq $z_educ $z_app_new $g_cities if lw06!=., robust

/* testing instruments in earnings eqn */
reg lw06 $x_earn $z_app_new broeduc siseduc $g_cities $skills, robust



****************************************
*** 1st stage linear control function ***
****************************************

/* linear prediction */
reg apppast male lhours exper expersq $z_app_new $g_cities $skills if lw06!=., robust
	predict applin, r

/* control not included because no educ included */

label variable applin "App Control"

reg apppast $x_earn  $z_app_new control $g_cities $skills,  robust

/* test endogeneity of apppast */
ivreg2 lw06 $x_earn (apppast = $z_app_new) control $g_cities $skills, first robust endog(apppast) 

exit

**********************************
******  OLS, Control, 2SLS *******
**********************************

start
	*est2vec earnings, replace vars($x_earn control apppast appdmeduc newraven applin) e(r2) name(nocontrols)

*baseline1
	**est2vec earnings, addto(earnings) name(ols1)

baseline2
	*est2vec earnings, addto(earnings) name(ols2)

earnskills
	*est2vec earnings, addto(earnings) name(skills)

educonly
	*est2vec earnings, addto(earnings) name(control)

*nocontrol
	**est2vec earnings, addto(earnings) name(nocontrol)

interaction
	*est2vec earnings, addto(earnings) name(interaction)

app2sls
	*est2vec earnings, addto(earnings) name(twosls)

wool181
	*est2vec earnings, addto(earnings) name(wool181)

app2slsint
	*est2vec earnings, addto(earnings) name(twoslswint)

wool182
	*est2vec earnings, addto(earnings) name(wool182)

linfullmodel
	*est2vec earnings, addto(earnings) name(appandeducendog)


*est2tex earnings, preserve mark(stars)levels(90 95 99) fancy label replace


/* calculate ATThat & ATEhat (for a subsample, if needed) */
	capture drop step* 
	capture drop att
	predictnl step3 = apppast*(educ-avgeduc)*_b[appdmeduc]
	egen step4 = mean(step3) 
	predictnl att = _b[apppast] + step4*931/268
	sum att
/* can do at educ==0 as well */
	capture drop step* 
	capture drop att
	predictnl step3 = apppast*(educ-avgeduc)*_b[appdmeduc] if educ==0
	egen step4 = mean(step3) if educ==0
	predictnl att = _b[apppast] + step4*118/18 if educ==0
	sum att

	capture drop step* 
	capture drop att
	predictnl step3 = apppast*(educ-avgeduc)*_b[appdmeduc] if jssormid==1
	egen step4 = mean(step3) if jssormid==1
	predictnl att = _b[apppast] + step4*313/196 if jssormid==1
	sum att


*******************************************************************************************
******* with other app control function approach ********
*******************************************************************************************


linfullmodel
	*est2vec earningslin, addto(earningslin) name(appandeducendog)
	*est2tex earningslin, preserve  mark(stars)levels(90 95 99) fancy label replace

bootstrap educonly _b, reps(1000)
	matrix educonly_bse = e(se)'

bootstrap interaction _b, reps(1000)
	matrix interaction_bse = e(se)'

bootstrap app2sls _b, reps(1000)
	matrix app2sls_bse = e(se)'

bootstrap wool181 _b, reps(1000)
	matrix wool_bse = e(se)'

bootstrap app2slsint _b, reps(1000)
	matrix full_bse = e(se)'

bootstrap wool182 _b, reps(1000)
	matrix wool182_bse = e(se)'

bootstrap linfullmodel _b, reps(1000)
	matrix linfullmodel_bse = e(se)'

 
/*
foreach var of global x_earn {
	matrix earnings_se[rownumb(earnings_se,"`var'"),colnumb(earnings_se,"interaction")]   = interaction_bse[rownumb(interaction_bse,"b_`var'"),1]
	matrix earnings_se[rownumb(earnings_se,"`var'"),colnumb(earnings_se,"control")]   = educonly_bse[rownumb(educonly_bse,"b_`var'"),1]
	matrix earnings_se[rownumb(earnings_se,"`var'"),colnumb(earnings_se,"twosls")]  = app2sls_bse[rownumb(app2sls_bse,"b_`var'"),1]
	matrix earnings_se[rownumb(earnings_se,"`var'"),colnumb(earnings_se,"wool181")] = wool_bse[rownumb(wool_bse,"b_`var'"),1]
	matrix earnings_se[rownumb(earnings_se,"`var'"),colnumb(earnings_se,"twoslswint")]  = full_bse[rownumb(full_bse,"b_`var'"),1]
	matrix earnings_se[rownumb(earnings_se,"`var'"),colnumb(earnings_se,"wool182")]  = wool182_bse[rownumb(wool182_bse,"b_`var'"),1]
	matrix earnings_se[rownumb(earnings_se,"`var'"),colnumb(earnings_se,"appandeducendog")]  = linfullmodel_bse[rownumb(linfullmodel_bse,"b_`var'"),1]
}


foreach var in newraven control apppast {
	matrix earnings_se[rownumb(earnings_se,"`var'"),colnumb(earnings_se,"interaction")]   = interaction_bse[rownumb(interaction_bse,"b_`var'"),1]
	matrix earnings_se[rownumb(earnings_se,"`var'"),colnumb(earnings_se,"control")]   = educonly_bse[rownumb(educonly_bse,"b_`var'"),1]
	matrix earnings_se[rownumb(earnings_se,"`var'"),colnumb(earnings_se,"twosls")]  = app2sls_bse[rownumb(app2sls_bse,"b_`var'"),1]
	matrix earnings_se[rownumb(earnings_se,"`var'"),colnumb(earnings_se,"wool181")] = wool_bse[rownumb(wool_bse,"b_`var'"),1]
	matrix earnings_se[rownumb(earnings_se,"`var'"),colnumb(earnings_se,"twoslswint")]  = full_bse[rownumb(full_bse,"b_`var'"),1]
	matrix earnings_se[rownumb(earnings_se,"`var'"),colnumb(earnings_se,"wool182")]  = wool182_bse[rownumb(wool182_bse,"b_`var'"),1]
	matrix earnings_se[rownumb(earnings_se,"`var'"),colnumb(earnings_se,"appandeducendog")]  = linfullmodel_bse[rownumb(linfullmodel_bse,"b_`var'"),1]
}
foreach var in appdmeduc {
	matrix earnings_se[rownumb(earnings_se,"`var'"),colnumb(earnings_se,"interaction")]   = interaction_bse[rownumb(interaction_bse,"b_`var'"),1]
	matrix earnings_se[rownumb(earnings_se,"`var'"),colnumb(earnings_se,"twoslswint")]  = full_bse[rownumb(full_bse,"b_`var'"),1]
	matrix earnings_se[rownumb(earnings_se,"`var'"),colnumb(earnings_se,"wool182")]  = wool182_bse[rownumb(wool182_bse,"b_`var'"),1]
	matrix earnings_se[rownumb(earnings_se,"`var'"),colnumb(earnings_se,"appandeducendog")]  = linfullmodel_bse[rownumb(linfullmodel_bse,"b_`var'"),1]
}

foreach var in applin {
	matrix earnings_se[rownumb(earnings_se,"`var'"),colnumb(earnings_se,"appandeducendog")]  = linfullmodel_bse[rownumb(linfullmodel_bse,"b_`var'"),1]
}
*/


*est2tex earnings, preserve fancy label mark(stars) replace


exit

